pub struct EstimatedRefactorSavingsBytes(pub i64);Expand description
A model-derived estimate of a refactoring’s byte impact.
Estimates may be negative when required call overhead outweighs the duplicate bytes attributed to the proposed refactoring.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for EstimatedRefactorSavingsBytes
impl Clone for EstimatedRefactorSavingsBytes
Sourcefn clone(&self) -> EstimatedRefactorSavingsBytes
fn clone(&self) -> EstimatedRefactorSavingsBytes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EstimatedRefactorSavingsBytes
Sourceimpl<'de> Deserialize<'de> for EstimatedRefactorSavingsBytes
impl<'de> Deserialize<'de> for EstimatedRefactorSavingsBytes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EstimatedRefactorSavingsBytes
impl StructuralPartialEq for EstimatedRefactorSavingsBytes