pub struct RetainedSize {
pub symbol: ArtifactFingerprint,
pub retained_bytes: u64,
}Expand description
The bytes exclusively retained by one reachable symbol’s dominator region.
Fields
symbol: ArtifactFingerprintThe symbol whose removal makes the dominated region unreachable.
retained_bytes: u64Sum of observed code sizes in its dominated region.