pub struct VerifiedSavingsBytes(pub i64);Expand description
A before/after reduction verified for one controlled refactoring.
A verified change may be negative when the controlled change grows the artifact, so it cannot be represented by an unsigned observed count.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for VerifiedSavingsBytes
impl Clone for VerifiedSavingsBytes
Sourcefn clone(&self) -> VerifiedSavingsBytes
fn clone(&self) -> VerifiedSavingsBytes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VerifiedSavingsBytes
Sourceimpl Debug for VerifiedSavingsBytes
impl Debug for VerifiedSavingsBytes
Sourceimpl<'de> Deserialize<'de> for VerifiedSavingsBytes
impl<'de> Deserialize<'de> for VerifiedSavingsBytes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VerifiedSavingsBytes
Sourceimpl PartialEq for VerifiedSavingsBytes
impl PartialEq for VerifiedSavingsBytes
Sourceimpl Serialize for VerifiedSavingsBytes
impl Serialize for VerifiedSavingsBytes
impl StructuralPartialEq for VerifiedSavingsBytes