pub struct ArtifactImport {
pub module: Option<String>,
pub name: Option<String>,
pub kind: ArtifactImportKind,
}Expand description
A dependency the artifact declares without requiring it to be loaded.
Fields
module: Option<String>Importing module or library namespace, when the format uses one.
name: Option<String>Imported item name, when supplied by the format.
kind: ArtifactImportKindDeclared kind of the imported item.